package com.mdd.admin.controller.system;

import com.mdd.admin.service.ISystemLogsServer;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.system.SystemSearchLoginsValidate;
import com.mdd.admin.validate.system.SystemSearchOperateValidate;
import com.mdd.admin.vo.system.SystemLogLoginVo;
import com.mdd.admin.vo.system.SystemLogOperateAddVo;
import com.mdd.admin.vo.system.SystemLogOperateVo;
import com.mdd.common.aop.NotLogin;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/system/log"})
@Api(
   tags = {"系统日志管理"}
)
public class SystemLogsController {
   @Resource
   ISystemLogsServer iSystemLogsServer;

   @NotLogin
   @PostMapping({"/add"})
   @ApiOperation("添加日志")
   public AjaxResult<?> add(@RequestBody SystemLogOperateAddVo addVo) {
      this.iSystemLogsServer.add(addVo);
      return AjaxResult.success();
   }

   @PostMapping({"/delete"})
   @ApiOperation("删除日志")
   public AjaxResult<?> delete(@Validated SystemSearchOperateValidate validate) {
      this.iSystemLogsServer.delete(validate);
      return AjaxResult.success();
   }

   @GetMapping({"/operate"})
   @ApiOperation("系统操作日志")
   public AjaxResult<PageResult<SystemLogOperateVo>> operate(@Validated PageValidate pageValidate, @Validated SystemSearchOperateValidate searchValidate) {
      PageResult<SystemLogOperateVo> list = this.iSystemLogsServer.operate(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }

   @GetMapping({"/login"})
   @ApiOperation("系统登录日志")
   public AjaxResult<PageResult<SystemLogLoginVo>> login(@Validated PageValidate pageValidate, @Validated SystemSearchLoginsValidate searchValidate) {
      PageResult<SystemLogLoginVo> list = this.iSystemLogsServer.login(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }
}
